@@ -7,7 +7,7 @@ def discover_devices(timeout=30, debug=False):
     Discovers Nanoleaf devices on the network using SSDP
 
     :param timeout: The timeout on the search in seconds (default 30)
-    :param debug: Prints each device string in for the SSDP discovery
+    :param debug: Prints each device string for the SSDP discovery
     :returns: Dictionary of found devices in format {name: ip}
     """
     ssdp = "M-SEARCH * HTTP/1.1\r\nHOST: 239.255.255.250:1900\r\nMAN: \"ssdp:discover\"\r\nMX: 1\r\nST: nanoleaf:nl29\r\n\r\n"
@@ -34,8 +34,9 @@ def discover_devices(timeout=30, debug=False):
         ip = None
         name = None
         for header in headers:
-            if "Location" in header:
-                ip = header.split("http://")[1][:-6]
+            if "Location" or "LOCATION" in header:
+                ip_string = header.split("http://")[1]
+                ip = ip_string.split(":")[0]
             if "nl-devicename" in header:
                 name = header.split("nl-devicename: ")[1]
         if ip is not None:
